==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_basic.js <==
_me = obj_hmenu_basic.prototype;
function obj_hmenu_basic(){};

_me.__constructor = function() {

	var aMenu = [
		{"title":'MAIN_MENU::UPDATE',"arg":'get',"css":'ico_get'},
		{"title":'MAIN_MENU::NEW', "css":'ico_new', "arg":'new'}
	];

	if (sPrimaryAccountGW>0){

		aMenu[1].nodes = {"mail": {"arg": 'new_mail', "title": 'MAIN_MENU::NEW_MAIL', "css": 'ico_m'}};

        var dgw = GWOthers.getItem('RESTRICTIONS', 'disable_gw_types');
		if(!dgw || dgw.indexOf('c')<0){
			aMenu[1].nodes.contact = {"arg": 'new_contact', "title": 'MAIN_MENU::NEW_CONTACT', "css": 'ico_c'};
			aMenu[1].nodes.distrib = {"arg": 'new_distrib', "title": 'MAIN_MENU::NEW_DISTRIB_LIST', "css": 'ico_d'};
		}

		if(!dgw || dgw.indexOf('e')<0)
			aMenu[1].nodes.event = {"arg": 'new_event', "title": 'MAIN_MENU::NEW_EVENT', "css": 'ico_e'};

		if(!dgw || dgw.indexOf('t')<0)
			aMenu[1].nodes.task = {"arg": 'new_task', "title": 'MAIN_MENU::NEW_TASK', "css": 'ico_t'};

		if(!dgw || dgw.indexOf('j')<0)
			aMenu[1].nodes.journal = {"arg": 'new_journal', "title": 'MAIN_MENU::NEW_JOURNAL', "css": 'ico_j'};

		if(!dgw || dgw.indexOf('n')<0)
			aMenu[1].nodes.note = {"arg": 'new_note', "title": 'MAIN_MENU::NEW_NOTE', "css": 'ico_n'};

		if(!dgw || dgw.indexOf('f')<0)
			aMenu[1].nodes.file = {"arg": 'new_file', "title": 'MAIN_MENU::NEW_FILE', "css": 'ico_f'};

		aMenu[1].nodes.folder = {"arg": 'new_folder', "title": 'MAIN_MENU::NEW_FOLDER', "css": 'ico_o'};
	}
	else
        aMenu[1].nodes = {
			"mail": {"arg": 'new_mail', "title": 'MAIN_MENU::NEW_MAIL', "css": 'ico_m'},
            "folder": {"arg": 'new_folder', "title": 'MAIN_MENU::NEW_FOLDER', "css": 'ico_o'}
		}


	var aTools = {"options": {"arg": 'options', "title": 'MAIN_MENU::OPTIONS'}};
	switch (sPrimaryAccountType) {
		case 'admin':
			aTools["admin_options"] = {"arg": 'admin_options', "title": 'MAIN_MENU::ADMIN_OPTIONS'};
			break;
		case 'domainadmin':
			aTools["domainadmin_options"] = {"arg": 'domainadmin_options', "title": 'MAIN_MENU::DOMAIN_OPTIONS'};
			break;
	}
	aTools["rules"] = {"arg": 'rules', "title": 'MAIN_MENU::RULES'};
	aTools["accounts"] = {"arg": 'accounts', "title": 'MAIN_MENU::ACCOUNTS'};
	aTools["help"] = {"arg": 'help', "title": 'MAIN_MENU::HELP'};
	
	aMenu.push({
		"title":'MAIN_MENU::TOOLS',
		"css":'ico_tools',
		"arg":'options',
		"nodes": aTools
	});

	this._fill(aMenu,'static');

	// AUTOUPDATE
	storage.library('gw_others');
	var aSettingsGeneral = GWOthers.get('MAIL_SETTINGS_GENERAL','storage');
        aSettingsGeneral = aSettingsGeneral.VALUES;

	if (aSettingsGeneral.autoupdate){
		var refresh = parseInt(aSettingsGeneral.autoupdate_minutes);
		if (refresh>0){
            refresh *= 60000;
            this.__interval = setInterval('try{'+this._pathName+'._getEmails(1);}catch(e){try{clearInterval('+this._pathName+'.__interval);}catch(e){}}',refresh);
		}
	}
};

_me._onclick = function(e,elm,id,arg)
{
	switch(arg)
	{
		case 'get':
			this._getEmails();
			break;
			
		case 'new': this.__createNew(); break;
		case 'new_mail': NewMessage.compose(); break;
		case 'new_contact': this.__createNewGW('C'); break;
		case 'new_distrib': this.__createNewGW('L'); break;
		case 'new_event':
			if (gui.frm_main.main && (gui.frm_main.main._type == 'frm_main_calendar_dayweek' || gui.frm_main.main._type == 'frm_main_calendar_month')) {
		        gui.frm_main.main._createEvent();
			} else {
		    	this.__createNewGW('E');
			}
			break;
		case 'new_journal': this.__createNewGW('J'); break;
		case 'new_note': this.__createNewGW('N'); break;
		case 'new_task': this.__createNewGW('T'); break;
		case 'new_file': this.__createNewGW('F'); break;
		case 'new_folder': gui._create('frm_add_folder','frm_add_folder','','',sPrimaryAccount); break;
		case 'accounts': gui._create('accounts','frm_accounts'); break;
		case 'options': gui._create('settings','frm_settings'); break;
		case 'admin_options': gui._create('settings','frm_settings_admin'); break;
		case 'domainadmin_options': gui._create('settings','frm_settings_admin','','',true); break;
		case 'rules': gui._create('rules', 'frm_rules'); break;
		case 'help':
			if (gui.help)
                gui.help._destruct();
			else
				gui._create('help', 'frm_help');

			break;
		
		//case 'print':
	}
};

/**
 * @param bMain - bool - main account only
 **/
_me._getEmails = function(bMain)
{
	var aAccounts = dataSet.get('accounts');
	if (!aAccounts)	return;

	var disable_other = (GWOthers.getItem('RESTRICTIONS','disable_otheraccounts') == 1);

	for(var sAccId in aAccounts){
		if (!aAccounts[sAccId]) continue;
		if (!aAccounts[sAccId]['PRIMARY'] && disable_other) return;
		accounts.refresh({'aid':sAccId},'folders','',[this,'__refreshItems',[sAccId]]);
        if (bMain) return;
	}
};

_me.__refreshItems = function(sAccId)
{
	var aSelected = this._parent.folders._getActive();

	if (aSelected[0] == sAccId && aSelected[1])
	{
		var sFolID = aSelected[1];

		if (dataSet.get('folders',[sAccId,sFolID]))
			gui.frm_main.folders._handleNode({'aid':sAccId,'fid':sFolID},true);
		else{
			if (gui.frm_main.main)
				gui.frm_main.main._destruct();

			this._parent.folders._invalidateActive();
			gui.frm_main._lastView = '';
			gui.frm_main.hmenu3._fill();

			dataSet.remove('items');
			dataSet.remove('mailview');
		}
	}
};

_me.__createNew = function() {

    var aActive = gui.frm_main.folders._getActive();
    if (aActive[0] == '' || aActive[1] == '') {
        NewMessage.compose();
	} else {
		var sType = dataSet.get('folders', [aActive[0], aActive[1], 'TYPE']);
		switch (sType) {
			case 'E':
				if (gui.frm_main.main._type == 'frm_main_calendar_dayweek' || gui.frm_main.main._type == 'frm_main_calendar_month') {
					gui.frm_main.main._createEvent();
				} else {
					gui._create('gw', Mapping.getFormNameByGWType('E'), '', '', aActive[0], aActive[1], '', getActualEventTime());
				}
				break;

			case 'QL':
				gui._create('gw', 'frm_blackwhite', '', '', aActive[0], aActive[1]);
				break;

			case 'Q':
				//Neimplementovno
				break;
				
			case 'C':
			case 'N':
			case 'T':
			case 'J':
			case 'L':
			case 'F':
				gui._create('gw', Mapping.getFormNameByGWType(sType), '', '', aActive[0], aActive[1]);
				break;
			
			case 'M':
			default:
				NewMessage.compose();
				break;
		}
	}
};

_me.__createNewGW = function(sType) {
	var aActive = gui.frm_main.folders._getActive();
	var sFolder;
	var sAccount;
	var bActual = false;

	// Pokud je aktualni folder stejneho typu, jako vytvarena polozka, bude vytvorena
	// v danem folderu, jinak se vezme defaultni folder pro dany typ polozky
	if (aActive[0] != '' || aActive[1] != '') {
		var sFolType = dataSet.get('folders', [aActive[0], aActive[1], 'TYPE']);
		if (sType == sFolType || (sType == 'L' && sFolType == 'C'))
			bActual = true;
	}

	if (bActual) {
		sAccount = aActive[0];
		sFolder = aActive[1];
	} else {
		sAccount = sPrimaryAccount;
		sFolder = Mapping.getDefaultFolderForGWType(sType);
	}
	if (sType == 'E')
		gui._create('gw', Mapping.getFormNameByGWType('E'), '', '', sAccount, sFolder, '', getActualEventTime());
	else
		gui._create('gw', Mapping.getFormNameByGWType(sType), '', '', sAccount, sFolder );

};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_basic.js <==
_me = obj_hmenu_basic.prototype;
function obj_hmenu_basic(){};

_me.__constructor = function() {

	var aMenu = [
		{"anchor":'loader',"css":'loader'},
		{"title":'MAIN_MENU::UPDATE',"arg":'get',"css":'ico_get'},
		{"title":'MAIN_MENU::NEW', "css":'ico_new', "arg":'new'}
	];

	if (sPrimaryAccountGW>0){

		aMenu[2].nodes = {"mail": {"arg": 'new_mail', "title": 'MAIN_MENU::NEW_MAIL', "css": 'ico_m'}};

        var dgw = GWOthers.getItem('RESTRICTIONS', 'disable_gw_types');
		if(!dgw || dgw.indexOf('c')<0){
			aMenu[2].nodes.contact = {"arg": 'new_contact', "title": 'MAIN_MENU::NEW_CONTACT', "css": 'ico_c'};
			aMenu[2].nodes.distrib = {"arg": 'new_distrib', "title": 'MAIN_MENU::NEW_DISTRIB_LIST', "css": 'ico_d'};
		}

		if(!dgw || dgw.indexOf('e')<0)
			aMenu[2].nodes.event = {"arg": 'new_event', "title": 'MAIN_MENU::NEW_EVENT', "css": 'ico_e'};

		if(!dgw || dgw.indexOf('t')<0)
			aMenu[2].nodes.task = {"arg": 'new_task', "title": 'MAIN_MENU::NEW_TASK', "css": 'ico_t'};

		if(!dgw || dgw.indexOf('j')<0)
			aMenu[2].nodes.journal = {"arg": 'new_journal', "title": 'MAIN_MENU::NEW_JOURNAL', "css": 'ico_j'};

		if(!dgw || dgw.indexOf('n')<0)
			aMenu[2].nodes.note = {"arg": 'new_note', "title": 'MAIN_MENU::NEW_NOTE', "css": 'ico_n'};

		if(!dgw || dgw.indexOf('f')<0)
			aMenu[2].nodes.file = {"arg": 'new_file', "title": 'MAIN_MENU::NEW_FILE', "css": 'ico_f'};

		aMenu[2].nodes.folder = {"arg": 'new_folder', "title": 'MAIN_MENU::NEW_FOLDER', "css": 'ico_o'};
	}
	else
        aMenu[2].nodes = {
			"mail": {"arg": 'new_mail', "title": 'MAIN_MENU::NEW_MAIL', "css": 'ico_m'},
            "folder": {"arg": 'new_folder', "title": 'MAIN_MENU::NEW_FOLDER', "css": 'ico_o'}
		}


	var aTools = {"options": {"arg": 'options', "title": 'MAIN_MENU::OPTIONS'}};
	switch (sPrimaryAccountType) {
		case 'admin':
			aTools["admin_options"] = {"arg": 'admin_options', "title": 'MAIN_MENU::ADMIN_OPTIONS'};
			break;
		case 'domainadmin':
			aTools["domainadmin_options"] = {"arg": 'domainadmin_options', "title": 'MAIN_MENU::DOMAIN_OPTIONS'};
			break;
	}
	aTools["rules"] = {"arg": 'rules', "title": 'MAIN_MENU::RULES'};

	if (sPrimaryAccountSIP)
		aTools["calls"] = {"arg": 'calls', "title": 'MAIN_MENU::CALLS'};
		
	aTools["accounts"] = {"arg": 'accounts', "title": 'MAIN_MENU::ACCOUNTS'};
	aTools["export"] = {"arg": 'export', "title": 'MAIN_MENU::IMPORT_EXPORT'};
	aTools["help"] = {"arg": 'help', "title": 'MAIN_MENU::HELP'};

	aMenu.push({
		"title":'MAIN_MENU::TOOLS',
		"css":'ico_tools',
		"arg":'options',
		"nodes": aTools
	});

	this._fill(aMenu,'static');

	// AUTOUPDATE
	storage.library('gw_others');
	var aSettingsGeneral = GWOthers.get('MAIL_SETTINGS_GENERAL','storage');
        aSettingsGeneral = aSettingsGeneral.VALUES;

	if (aSettingsGeneral.autoupdate>0){
		var refresh = parseInt(aSettingsGeneral.autoupdate_minutes);
		if (refresh>0){
            refresh *= 60000;
            this.__interval = setInterval('try{'+this._pathName+'._getEmails(1);}catch(e){try{clearInterval('+this._pathName+'.__interval);}catch(e){}}',refresh);
		}
	}

	//loading
	this._add_destructor('__destructor');
    gui.__loading_counter = 0;
	gui.__loading_obj = this;
};

_me.__destructor = function(){
	if (gui.__loading_obj === this)
		gui.__loading_obj = null;
};

/**
 * loading controler
 **/
_me._loading = function(b){
	var elm = this._getAnchor('loader');

	if (b>0)
        elm.className = 'loader loader_start';
	else
        elm.className = 'loader';
	    //removecss(elm,'loader_start');
};

_me._onclick = function(e,elm,id,arg)
{
	switch(arg)
	{
		case 'get':
			this._getEmails();
			break;
			
		case 'new': this.__createNew(); break;
		case 'new_mail': NewMessage.compose(); break;
		case 'new_contact': this.__createNewGW('C'); break;
		case 'new_distrib': this.__createNewGW('L'); break;
		case 'new_event':
			if (gui.frm_main.main && (gui.frm_main.main._type == 'frm_main_calendar_dayweek' || gui.frm_main.main._type == 'frm_main_calendar_month')) {
		        gui.frm_main.main._createEvent();
			} else {
		    	this.__createNewGW('E');
			}
			break;
		case 'new_journal': this.__createNewGW('J'); break;
		case 'new_note': this.__createNewGW('N'); break;
		case 'new_task': this.__createNewGW('T'); break;
		case 'new_file': this.__createNewGW('F'); break;
		case 'new_folder': gui._create('frm_add_folder','frm_add_folder','','',sPrimaryAccount); break;
		case 'accounts': gui._create('accounts','frm_accounts'); break;
		case 'options': gui._create('settings','frm_settings'); break;
		case 'admin_options': gui._create('settings','frm_settings_admin'); break;
		case 'domainadmin_options': gui._create('settings','frm_settings_admin','','',true); break;
        case 'export': gui._create('backup', 'frm_backup'); break;
		case 'rules': gui._create('rules', 'frm_rules'); break;
		case 'calls': gui._create('dial','frm_dial','',''); break;
		case 'help':
			if (gui.help)
                gui.help._destruct();
			else
				gui._create('help', 'frm_help');

			break;
		
		//case 'print':
	}
};

/**
 * @param bMain - bool - main account only
 **/
_me._getEmails = function(bMain)
{
	var aAccounts = dataSet.get('accounts');
	if (!aAccounts)	return;

	var disable_other = (GWOthers.getItem('RESTRICTIONS','disable_otheraccounts') == 1);

	for(var sAccId in aAccounts){
		if (!aAccounts[sAccId])
			continue;

		if (!aAccounts[sAccId]['PRIMARY'] && (bMain || (disable_other && aAccounts[sAccId]['TYPE']!='rss')))
			continue;

		accounts.refresh({'aid':sAccId},'folders','',[gui.frm_main,'_refreshItems',[sAccId]]);
        if (bMain) return;
	}
};

_me.__createNew = function() {

    var aActive = gui.frm_main.folders._getActive();
    if (aActive[0] == '' || aActive[1] == '') {
        NewMessage.compose();
	} else {
		var sType = dataSet.get('folders', [aActive[0], aActive[1], 'TYPE']);
		switch (sType) {
			case 'E':
				if (gui.frm_main.main._type == 'frm_main_calendar_dayweek' || gui.frm_main.main._type == 'frm_main_calendar_month') {
					gui.frm_main.main._createEvent();
				} else {
					gui._create('gw', Mapping.getFormNameByGWType('E'), '', '', aActive[0], aActive[1], '', getActualEventTime());
				}
				break;

			case 'QL':
				gui._create('gw', 'frm_blackwhite', '', '', aActive[0], aActive[1]);
				break;

			case 'Q':
				//Neimplementovno
				break;
				
			case 'C':
			case 'N':
			case 'T':
			case 'J':
			case 'L':
			case 'F':
				gui._create('gw', Mapping.getFormNameByGWType(sType), '', '', aActive[0], aActive[1]);
				break;
			
			case 'M':
			default:
				NewMessage.compose();
				break;
		}
	}
};

_me.__createNewGW = function(sType) {
	var aActive = gui.frm_main.folders._getActive();
	var sFolder;
	var sAccount;
	var bActual = false;

	// Pokud je aktualni folder stejneho typu, jako vytvarena polozka, bude vytvorena
	// v danem folderu, jinak se vezme defaultni folder pro dany typ polozky
	if (aActive[0] != '' || aActive[1] != '') {
		var sFolType = dataSet.get('folders', [aActive[0], aActive[1], 'TYPE']);
		if (sType == sFolType || (sType == 'L' && sFolType == 'C'))
			bActual = true;
	}

	if (bActual) {
		sAccount = aActive[0];
		sFolder = aActive[1];
	} else {
		sAccount = sPrimaryAccount;
		sFolder = Mapping.getDefaultFolderForGWType(sType);
	}
	if (sType == 'E')
		gui._create('gw', Mapping.getFormNameByGWType('E'), '', '', sAccount, sFolder, '', getActualEventTime());
	else
		gui._create('gw', Mapping.getFormNameByGWType(sType), '', '', sAccount, sFolder );

};
